@@ -2,6 +2,8 @@
  * disalloc.c - aeb - 940501 - Disallocate virtual terminal(s)
  * Renamed deallocvt.
  */
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
@@ -15,11 +17,11 @@
 #include "version.h"
 #include "kbd_error.h"
 
-int
-main(int argc, char *argv[]) {
+int main(int argc, char *argv[])
+{
 	int fd, num, i;
 
-	if (argc < 1)		/* unlikely */
+	if (argc < 1) /* unlikely */
 		return EXIT_FAILURE;
 	set_progname(argv[0]);
 
@@ -37,23 +39,26 @@ main(int argc, char *argv[]) {
 		}
 	}
 
-	fd = getfd(NULL);
+	if ((fd = getfd(NULL)) < 0)
+		kbd_error(EXIT_FAILURE, 0, _("Couldn't get a file descriptor referring to the console"));
 
 	if (argc == 1) {
 		/* deallocate all unused consoles */
-		if (ioctl(fd,VT_DISALLOCATE,0)) {
+		if (ioctl(fd, VT_DISALLOCATE, 0)) {
 			kbd_error(EXIT_FAILURE, errno, "ioctl VT_DISALLOCATE");
 		}
-	} else for (i = 1; i < argc; i++) {
-		num = atoi(argv[i]);
-		if (num == 0) {
-			kbd_error(EXIT_FAILURE, 0, _("0: illegal VT number\n"));
-		} else if (num == 1) {
-			kbd_error(EXIT_FAILURE, 0, _("VT 1 is the console and cannot be deallocated\n"));
-		} else if (ioctl(fd,VT_DISALLOCATE,num)) {
-			kbd_error(EXIT_FAILURE, errno, _("could not deallocate console %d: "
-			                                 "ioctl VT_DISALLOCATE"), num);
+	} else
+		for (i = 1; i < argc; i++) {
+			num = atoi(argv[i]);
+			if (num == 0) {
+				kbd_error(EXIT_FAILURE, 0, _("0: illegal VT number\n"));
+			} else if (num == 1) {
+				kbd_error(EXIT_FAILURE, 0, _("VT 1 is the console and cannot be deallocated\n"));
+			} else if (ioctl(fd, VT_DISALLOCATE, num)) {
+				kbd_error(EXIT_FAILURE, errno, _("could not deallocate console %d: "
+				                                 "ioctl VT_DISALLOCATE"),
+				          num);
+			}
 		}
-	}
-	exit(0);
+	exit(EXIT_SUCCESS);
 }
