@@ -3,6 +3,8 @@
  *
  * derived from version 0.81 - aeb@cwi.nl
  */
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
@@ -19,11 +21,13 @@
 #include "modifiers.h"
 #include "nls.h"
 #include "version.h"
+#include "kbd_error.h"
 
 static int fd;
 
-static void __attribute__ ((noreturn))
-usage(void) {
+static void __attribute__((noreturn))
+usage(void)
+{
 	fprintf(stderr, _("dumpkeys version %s"), PACKAGE_VERSION);
 	fprintf(stderr, _("\
 \n\
@@ -33,51 +37,56 @@ valid options are:\n\
 \n\
 	-h --help	    display this help text\n\
 	-i --short-info	    display information about keyboard driver\n\
-	-l --long-info	    display above and symbols known to loadkeys\n\
+	-l -s --long-info   display above and symbols known to loadkeys\n\
 	-n --numeric	    display keytable in hexadecimal notation\n\
 	-f --full-table	    don't use short-hand notations, one row per keycode\n\
 	-1 --separate-lines one line per (modifier,keycode) pair\n\
-	   --funcs-only	    display only the function key strings\n\
-	   --keys-only	    display only key bindings\n\
-	   --compose-only   display only compose key combinations\n\
+	-S --shape=\n\
+	-t --funcs-only	    display only the function key strings\n\
+	-k --keys-only	    display only key bindings\n\
+	-d --compose-only   display only compose key combinations\n\
 	-c --charset="));
 	lk_list_charsets(stderr);
 	fprintf(stderr, _("\
 			    interpret character action codes to be from the\n\
 			    specified character set\n\
+"));
+	fprintf(stderr, _("\
+	-v --verbose\n\
+	-V --version	    print version number\n\
 "));
 	exit(1);
 }
 
-int
-main (int argc, char *argv[]) {
-	const char *short_opts = "hilvsnf1tkdS:c:V";
+int main(int argc, char *argv[])
+{
+	const char *short_opts          = "hilvsnf1tkdS:c:V";
 	const struct option long_opts[] = {
-		{ "help",	no_argument,		NULL, 'h' },
-		{ "short-info",	no_argument,		NULL, 'i' },
-		{ "long-info",	no_argument,		NULL, 'l' },
-		{ "numeric",	no_argument,		NULL, 'n' },
-		{ "full-table",	no_argument,		NULL, 'f' },
-		{ "separate-lines",no_argument,		NULL, '1' },
-		{ "shape",	required_argument,	NULL, 'S' },
-		{ "funcs-only",	no_argument,		NULL, 't' },
-		{ "keys-only",	no_argument,		NULL, 'k' },
-		{ "compose-only",no_argument,		NULL, 'd' },
-		{ "charset",	required_argument,	NULL, 'c' },
-		{ "verbose",	no_argument,		NULL, 'v' },
-		{ "version",	no_argument,		NULL, 'V' },
-		{ NULL,	0, NULL, 0 }
+		{ "help", no_argument, NULL, 'h' },
+		{ "short-info", no_argument, NULL, 'i' },
+		{ "long-info", no_argument, NULL, 'l' },
+		{ "numeric", no_argument, NULL, 'n' },
+		{ "full-table", no_argument, NULL, 'f' },
+		{ "separate-lines", no_argument, NULL, '1' },
+		{ "shape", required_argument, NULL, 'S' },
+		{ "funcs-only", no_argument, NULL, 't' },
+		{ "keys-only", no_argument, NULL, 'k' },
+		{ "compose-only", no_argument, NULL, 'd' },
+		{ "charset", required_argument, NULL, 'c' },
+		{ "verbose", no_argument, NULL, 'v' },
+		{ "version", no_argument, NULL, 'V' },
+		{ NULL, 0, NULL, 0 }
 	};
 	int c, rc;
 	int kbd_mode;
 
-	char long_info = 0;
-	char short_info = 0;
-	char numeric = 0;
+	char long_info       = 0;
+	char short_info      = 0;
+	char numeric         = 0;
 	lk_table_shape table = LK_SHAPE_DEFAULT;
-	char funcs_only = 0;
-	char keys_only = 0;
-	char diac_only = 0;
+	char funcs_only      = 0;
+	char keys_only       = 0;
+	char diac_only       = 0;
 
 	struct lk_ctx *ctx;
 
@@ -93,7 +102,7 @@ main (int argc, char *argv[]) {
 	}
 
 	while ((c = getopt_long(argc, argv,
-		short_opts, long_opts, NULL)) != -1) {
+	                        short_opts, long_opts, NULL)) != -1) {
 		switch (c) {
 			case 'i':
 				short_info = 1;
@@ -129,7 +138,7 @@ main (int argc, char *argv[]) {
 			case 'c':
 				if ((lk_set_charset(ctx, optarg)) != 0) {
 					fprintf(stderr, _("unknown charset %s - ignoring charset request\n"),
-						optarg);
+					        optarg);
 					usage();
 				}
 				printf("charset \"%s\"\n", optarg);
@@ -145,12 +154,13 @@ main (int argc, char *argv[]) {
 	if (optind < argc)
 		usage();
 
-	fd = getfd(NULL);
+	if ((fd = getfd(NULL)) < 0)
+		kbd_error(EXIT_FAILURE, 0, _("Couldn't get a file descriptor referring to the console"));
 
 	/* check whether the keyboard is in Unicode mode */
 	if (ioctl(fd, KDGKBMODE, &kbd_mode)) {
 		fprintf(stderr, _("%s: error reading keyboard mode: %m\n"),
-			progname);
+		        progname);
 		exit(EXIT_FAILURE);
 	}
 
@@ -166,7 +176,7 @@ main (int argc, char *argv[]) {
 
 		if (long_info) {
 			printf(_("Symbols recognized by %s:\n(numeric value, symbol)\n\n"),
-				progname);
+			       progname);
 			lk_dump_symbols(ctx, stdout);
 		}
 		exit(EXIT_SUCCESS);
@@ -175,9 +185,9 @@ main (int argc, char *argv[]) {
 #ifdef KDGKBDIACR
 	if (!diac_only) {
 #endif
-	if (!funcs_only) {
-		lk_dump_keymap(ctx, stdout, table, numeric);
-	}
+		if (!funcs_only) {
+			lk_dump_keymap(ctx, stdout, table, numeric);
+		}
 #ifdef KDGKBDIACR
 	}
 
@@ -185,7 +195,8 @@ main (int argc, char *argv[]) {
 		lk_dump_diacs(ctx, stdout);
 #endif
 
- fail:	lk_free(ctx);
+fail:
+	lk_free(ctx);
 	close(fd);
 
 	if (rc < 0)
