@@ -6,6 +6,7 @@
  * This file is covered by the GNU General Public License,
  * which should be included with kbd as the file COPYING.
  */
+#include "config.h"
 #include <string.h>
 #include <errno.h>
 #include <sys/ioctl.h>
@@ -17,7 +18,6 @@
 #include "ksyms.h"
 #include "modifiers.h"
 
-
 static char
 valid_type(int fd, int t)
 {
@@ -27,7 +27,7 @@ valid_type(int fd, int t)
 	ke.kb_table = 0;
 	ke.kb_value = K(t, 0);
 
-	return (ioctl(fd, KDSKBENT, (unsigned long) &ke) == 0);
+	return (ioctl(fd, KDSKBENT, (unsigned long)&ke) == 0);
 }
 
 static unsigned char
@@ -39,23 +39,22 @@ maximum_val(int fd, int t)
 	ke.kb_index = 0;
 	ke.kb_table = 0;
 	ke.kb_value = K_HOLE;
-	ke0 = ke;
+	ke0         = ke;
 
-	ioctl(fd, KDGKBENT, (unsigned long) &ke0);
+	ioctl(fd, KDGKBENT, (unsigned long)&ke0);
 
 	for (i = 0; i < 256; i++) {
 		ke.kb_value = K(t, i);
-		if (ioctl(fd, KDSKBENT, (unsigned long) &ke))
+		if (ioctl(fd, KDSKBENT, (unsigned long)&ke))
 			break;
 	}
 	ke.kb_value = K_HOLE;
-	ioctl(fd, KDSKBENT, (unsigned long) &ke0);
+	ioctl(fd, KDSKBENT, (unsigned long)&ke0);
 
 	return i - 1;
 }
 
-int
-lk_get_kmapinfo(struct lk_ctx *ctx, struct kmapinfo *res)
+int lk_get_kmapinfo(struct lk_ctx *ctx, struct kmapinfo *res)
 {
 	int i;
 
@@ -85,8 +84,7 @@ lk_get_kmapinfo(struct lk_ctx *ctx, struct kmapinfo *res)
 
 #define NR_TYPES 15
 
-void
-lk_dump_summary(struct lk_ctx *ctx, FILE *fd, int console)
+void lk_dump_summary(struct lk_ctx *ctx, FILE *fd, int console)
 {
 	int i;
 	struct kmapinfo info;
@@ -95,60 +93,59 @@ lk_dump_summary(struct lk_ctx *ctx, FILE *fd, int console)
 		return;
 
 	fprintf(fd, _("keycode range supported by kernel:           1 - %d\n"),
-		NR_KEYS - 1);
+	        NR_KEYS - 1);
 	fprintf(fd, _("max number of actions bindable to a key:         %d\n"),
-		MAX_NR_KEYMAPS);
+	        MAX_NR_KEYMAPS);
 	fprintf(fd, _("number of keymaps in actual use:                 %u\n"),
-		(unsigned int) info.keymaps);
+	        (unsigned int)info.keymaps);
 
 	fprintf(fd, _("of which %u dynamically allocated\n"),
-		(unsigned int) info.keymaps_alloced);
+	        (unsigned int)info.keymaps_alloced);
 
 	fprintf(fd, _("ranges of action codes supported by kernel:\n"));
 
 	for (i = 0; i < NR_TYPES && valid_type(console, i); i++)
 		fprintf(fd, "	0x%04x - 0x%04x\n",
-			K(i, 0), K(i, maximum_val(console, i)));
+		        K(i, 0), K(i, maximum_val(console, i)));
 
 	fprintf(fd, _("number of function keys supported by kernel: %d\n"),
-		MAX_NR_FUNC);
+	        MAX_NR_FUNC);
 	fprintf(fd, _("max nr of compose definitions: %d\n"),
-		MAX_DIACR);
+	        MAX_DIACR);
 	fprintf(fd, _("nr of compose definitions in actual use: %u\n"),
-		(unsigned int) info.composes);
+	        (unsigned int)info.composes);
 }
 
-void
-lk_dump_symbols(struct lk_ctx *ctx, FILE *fd)
+void lk_dump_symbols(struct lk_ctx *ctx, FILE *fd)
 {
 	unsigned int t, v;
 	modifier_t *mod;
 	const char *p;
 
 	for (t = 0; t < syms_size; t++) {
-	    if (get_sym_size(ctx, t)) {
-		for (v = 0; v < get_sym_size(ctx, t); v++) {
-			if ((p = get_sym(ctx, t, v))[0])
-				fprintf(fd, "0x%04x\t%s\n", K(t, v), p);
+		if (get_sym_size(ctx, t)) {
+			for (v = 0; v < get_sym_size(ctx, t); v++) {
+				if ((p = get_sym(ctx, t, v))[0])
+					fprintf(fd, "0x%04x\t%s\n", K(t, v), p);
+			}
+		} else if (t == KT_META) {
+			for (v = 0; v < get_sym_size(ctx, KT_LATIN) && v < 128; v++) {
+				if ((p = get_sym(ctx, KT_LATIN, v))[0])
+					fprintf(fd, "0x%04x\tMeta_%s\n", K(t, v), p);
+			}
 		}
-	    } else if (t == KT_META) {
-		for (v = 0; v < get_sym_size(ctx, KT_LATIN) && v < 128; v++) {
-			if ((p = get_sym(ctx, KT_LATIN, v))[0])
-				fprintf(fd, "0x%04x\tMeta_%s\n", K(t, v), p);
-		}
-	    }
 	}
 
 	fprintf(fd, _("\nThe following synonyms are recognized:\n\n"));
 
 	for (t = 0; t < syn_size; t++) {
 		fprintf(fd, _("%-15s for %s\n"),
-			synonyms[t].synonym, synonyms[t].official_name);
+		        synonyms[t].synonym, synonyms[t].official_name);
 	}
 
 	fprintf(fd, _("\nRecognized modifier names and their column numbers:\n"));
 
-	mod = (modifier_t *) modifiers;
+	mod = (modifier_t *)modifiers;
 	while (mod->name) {
 		fprintf(fd, "%s\t\t%3d\n", mod->name, 1 << mod->bit);
 		mod++;
